SystemOrganization addCategory: #ConfigurationOfBenchmarking!

Object subclass: #ConfigurationOfBenchmarking
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfBenchmarking'!

!ConfigurationOfBenchmarking class methodsFor: 'development support' stamp: 'StefanMarr 5/14/2011 12:19'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfBenchmarking class methodsFor: 'private' stamp: 'StefanMarr 5/14/2011 12:19'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfBenchmarking class methodsFor: 'private' stamp: 'StefanMarr 5/14/2011 12:19'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfBenchmarking class methodsFor: 'private' stamp: 'StefanMarr 5/14/2011 12:19'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfBenchmarking class methodsFor: 'metacello tool support' stamp: 'StefanMarr 5/14/2011 12:19'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfBenchmarking class methodsFor: 'loading' stamp: 'StefanMarr 5/14/2011 12:19'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfBenchmarking class methodsFor: 'loading' stamp: 'StefanMarr 5/14/2011 12:19'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfBenchmarking class methodsFor: 'loading' stamp: 'StefanMarr 5/14/2011 12:19'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfBenchmarking class methodsFor: 'accessing' stamp: 'StefanMarr 5/14/2011 12:19'!
project

	^self new project! !

!ConfigurationOfBenchmarking class methodsFor: 'transporter' stamp: 'StefanMarr 5/25/2011 11:49'!
saveWithTransporter
	"Will save the package in file-out format using the Transporter infrastructure"
	self transporters
		ifNotNilDo: [:transporters | 
			transporters do: [:t | t saveNoPopup ]].! !

!ConfigurationOfBenchmarking class methodsFor: 'transporter' stamp: 'StefanMarr 5/22/2011 00:03'!
subPackages
	"Specifies the names of all logical subpackages of the Benchmarking package."
	"TODO: have a versioning for this, to better comply with the Metacello approach."
	^ {	'SMark'.
		'Scripting'.
		'NPB'.
		'CL-Benchmarks-Game'.
	}! !

!ConfigurationOfBenchmarking class methodsFor: 'transporter' stamp: 'StefanMarr 5/25/2011 11:48'!
transporters
	"Returns the transporters that define how to file out the different packages for versioning with Git."
	Smalltalk globals at: #Transporter ifPresent: [ :tpCls |
		^ self subPackages collect: [:pkg | tpCls forPackage: (PackageInfo named: pkg) ]
	].
	
	" Else "
	^ nil.! !

!ConfigurationOfBenchmarking class methodsFor: 'transporter' stamp: 'StefanMarr 5/25/2011 11:48'!
transportersForFileOutMenu
	^ self transporters! !

!ConfigurationOfBenchmarking class methodsFor: 'development support' stamp: 'StefanMarr 5/14/2011 12:19'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfBenchmarking methodsFor: 'baselines' stamp: 'StefanMarr 1/10/2012 23:07'!
baseline01: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/SMark'.
		self class subPackages do: [:pkg | spec package:  pkg ].
	].! !

!ConfigurationOfBenchmarking methodsFor: 'baselines' stamp: 'StefanMarr 1/13/2013 14:24'!
baseline02: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/SMark'.
		
		spec package: 'Scripting'.
		spec package: 'SMark' with: [
			spec requires: #(Scripting) ].
		
		spec package: 'NPB' with: [
			spec requires: #(SMark) ].
		spec package: 'CL-Benchmarks-Game' with: [
			spec requires: #(SMark) ].
		
		spec
			group: 'default'    with: #(Complete);
			group: 'Core'       with: #(SMark);
			group: 'Benchmarks' with: #(NPB 'CL-Benchmarks-Game');
			group: 'Complete'   with: #(Core Benchmarks)
	].! !

!ConfigurationOfBenchmarking methodsFor: 'symbolic versions' stamp: 'StefanMarr 2/13/2013 01:11'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.3'.
! !

!ConfigurationOfBenchmarking methodsFor: 'accessing' stamp: 'StefanMarr 5/14/2011 12:19'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfBenchmarking methodsFor: 'symbolic versions' stamp: 'StefanMarr 2/13/2013 01:11'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '0.3'.
! !

!ConfigurationOfBenchmarking methodsFor: 'versions' stamp: 'StefanMarr 5/14/2011 12:54'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: ''.
		spec author: 'StefanMarr'.
		spec timestamp: '5/14/2011 12:19'.
	].! !

!ConfigurationOfBenchmarking methodsFor: 'versions' stamp: 'StefanMarr 1/13/2013 14:48'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: ''.
		spec author: 'StefanMarr'.
		spec timestamp: '1/13/2013 14:24'.
		
		spec
			package: 'Scripting'          with: 'Scripting-StefanMarr.23';
			package: 'SMark'              with: 'SMark-StefanMarr.43';
			package: 'NPB'                with: 'NPB-StefanMarr.9';
			package: 'CL-Benchmarks-Game' with: 'CL-Benchmarks-Game-StefanMarr.27'.
	].! !

!ConfigurationOfBenchmarking methodsFor: 'versions' stamp: 'StefanMarr 2/13/2013 01:12'!
version03: spec
	<version: '0.3' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'stable'.
		spec description: 'Compatibility for Pharo 2.0'.
		spec author: 'StefanMarr'.
		spec timestamp: '2/13/2013 01:10'.
		
		spec
			package: 'Scripting'          with: 'Scripting-StefanMarr.23';
			package: 'SMark'              with: 'SMark-StefanMarr.45';
			package: 'NPB'                with: 'NPB-StefanMarr.9';
			package: 'CL-Benchmarks-Game' with: 'CL-Benchmarks-Game-StefanMarr.27'.
	].! !
